import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import ReactDropdown from 'react-dropdown';
import { useDataMap } from './useDataMap';
import { useDataNuclear } from './useDataNuclear';
import { Marks } from './Marks';
import { scaleLinear, extent } from 'd3';
import { Dropdown } from './Dropdown';

const width = 960;
const height = 500;

const attributes = [
  { value: 'COMBAT', label: 'Combat' },
  { value: 'FMS', label: 'Soviet Test (study)' },
  { value: 'ME', label: 'Military Exercise' },
  { value: 'PNE', label: 'Peaceful Nuclear Explosion' },
  { value: 'SAM', label: 'Soviet Test (accidental/emergency)' },
  { value: 'SSE', label: 'French/US Tests (safety testing)' },
  { value: 'TRANSP', label: 'Transportation-Storage Purposes' },
  { value: 'WE', label: 'British, French, US Evaluate Effects of Detonation' },
  { value: 'WR', label: 'Weapons Development Program' }
];

const App = () => {
  const mapData = useDataMap();
  const nuclearData = useDataNuclear();
  
  const initialAttribute = 'WR';
  const [attribute, setAttribute] = useState(initialAttribute);
  const purpose = d => d[attribute];
  //const purpose = d => d.purpose;
  console.log("Chosen: ", attribute);
  

  if (!mapData) {
    return <pre>Loading...</pre>;
  }

  if (!nuclearData) {
    return <pre>Loading...</pre>;
  }

  const longitude = d => d.longitude;
  const latitude = d => d.latitude;
  const name = d => d.name;


  return (
    <>
      <div className="menus-container">
        <span className="dropdown-label">Purpose of Deployments:</span>
        <ReactDropdown
          options={attributes}
          value={attribute}
          //onChange={event => console.log(event)}
          onChange={({ value }) => setAttribute(value)}
        />
      </div>
      <svg width={width} height={height}>
        <Marks
          mapData={mapData}
          nuclearData={nuclearData}
          longitude={longitude}
          latitude={latitude}
          name={name}
          purpose={attribute}
        />
      </svg>
    </>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
